import pandas as pd
import glob
from pythainlp.tokenize import word_tokenize
import pickle
import numpy as np
import os
#import pkg_resources
#path = 'botnoiw2v_small.mod'
#modloc = pkg_resources.resource_filename(__name__,path)

#mod = pickle.load(open(modloc))
def sentencevector(sentence,mod):
	wList = word_tokenize(str(sentence),engine='newmm')
	wvec = []
	for w in wList:
		try:
			wvec.append(mod[w])
		except:
			pass
	if len(wvec)==0:
		return np.zeros(50)

	return np.mean(wvec,0)


import io
import PIL
import pickle
import requests
from sklearn.preprocessing import normalize
import os
class text():
  def __init__(self,text):
    self.text = text

  def getw2v_light(self):
    from botnoi import getw2v as gw
    modpath = os.path.join(os.path.dirname(gw.__file__),'botnoiw2v_small.mod')
    mod = pickle.load(open(modpath,'rb'))
    #return modpath
    feat = gw.sentencevector(self.text,mod)
    feat = normalize([feat])[0]
    self.w2v_light = feat
    return feat

  def getbow_tfidf(self):
    from botnoi import getbow as gb
    modpath = os.path.join(os.path.dirname(gb.__file__),'botnoibow_tfidf.mod')
    mod = pickle.load(open(modpath,'rb'))
    #return modpath
    feat = gb.sentencevector(self.text,mod)
    feat = normalize(feat)[0]
    self.bow_tfidf = feat
    return feat

  def save(self,filename):
    pickle.dump(self,open(filename,'wb'))






#!/usr/bin/python
#-*-coding: utf-8 -*-
##from __future__ import absolute_import
######
from sklearn.feature_extraction.text import TfidfVectorizer
import pickle

import pandas as pd

#styledb = pd.read_pickle('allstyle.p')

def sentokenize(sentence):
    return list(sentence)

def trainsentencemod(outmod='mod.p'):
  trainsentence = styledb['Keyword'].astype('str').values 
  vectorizer = TfidfVectorizer(tokenizer=sentokenize,max_features=10000,decode_error='ignore',ngram_range=(0, 5))
  vectorizer.fit(trainsentence)
  pickle.dump(vectorizer,open(outmod,'wb'))

#vec = pickle.load(open('mod.p','rb'))

def encodesentence(sentence):
    return vec.transform(sentence)


#def createvectorizer():

